@@ -19,7 +19,7 @@
  * USA
  *
  * --------------------------------------------------------------------------
- * $Id: RouteBuilderComponent.java 19805 2010-05-02 11:27:19Z alitokmen $
+ * $Id: RouteBuilderComponent.java 19914 2010-06-02 16:19:39Z alitokmen $
  * --------------------------------------------------------------------------
  */
 package org.ow2.jonas.camel.component;
@@ -39,7 +39,11 @@ import org.apache.camel.LoggingLevel;
 import org.apache.camel.builder.RouteBuilder;
 import org.apache.camel.component.file.FileEndpoint;
 import org.apache.camel.component.jms.JmsComponent;
+import org.apache.camel.impl.DefaultCamelContext;
+import org.apache.camel.impl.JndiRegistry;
+import org.apache.camel.osgi.CompositeRegistry;
 import org.apache.camel.processor.interceptor.Tracer;
+import org.apache.camel.spi.Registry;
 import org.osgi.framework.BundleContext;
 import org.ow2.carol.jndi.intercept.spi.InterceptorInitialContextFactory;
 import org.ow2.carol.jndi.spi.MultiOrbInitialContextFactory;
@@ -54,6 +58,8 @@ import org.springframework.jms.support.destination.JndiDestinationResolver;
  * declarations</li>
  * <li>All CAMEL XML registry files and XML registry property files read from
  * <code>$JONAS_BASE/conf</code> and injected into the CAMEL context</li>
+ * <li>The local JNDI registry added to the CAMEL context's registry, to ease
+ * lookups with the <code>jdbc</code> component for instance</li>
  * <li>The JMS component bound on the JNDI registry</li>
  * <li>The bundle's {@link ClassLoader} positioned on the current thread, to
  * avoid any class loading issues with dynamic components such as JNDI, JMS or
@@ -155,13 +161,20 @@ public abstract class RouteBuilderComponent extends RouteBuilder {
 
             // Start a new Camel context for the application
             this.camelContextName = this.camelService.startNewContext();
-            CamelContext camelContext = this.camelService.getCamelContext(this.camelContextName);
+            DefaultCamelContext camelContext = (DefaultCamelContext) this.camelService.getCamelContext(this.camelContextName);
 
             // Add registry entries
             RegistryInjector injector = new RegistryInjector(this.registryReplacements);
             this.configureCamelComponents(camelContext, injector.getRegistryFilesContent());
             injector.injectRegistry(this.camelService, this.camelContextName);
 
+            // Add the JNDI registry
+            Registry jndiRegistry = new JndiRegistry(new InitialContext());
+            CompositeRegistry compositeRegistry = new CompositeRegistry();
+            compositeRegistry.addRegistry(camelContext.getRegistry());
+            compositeRegistry.addRegistry(jndiRegistry);
+            camelContext.setRegistry(compositeRegistry);
+
             // Add the routes in the camel context
             this.camelService.addRoutes(this, this.camelContextName);
 
